Installation
============

You will need Python and pip installed, as well as Brownie_ and either of `Ganache CLI`_ or Hardhat_ for the forked network functionality.
Make sure you have `Brownie networks`_ configured correctly.

Then you can simply:

.. code-block:: bash

   pip install -U ape-safe


.. _Brownie: https://eth-brownie.readthedocs.io/en/latest/install.html
.. _Hardhat: https://hardhat.org/getting-started/#installation
.. _Brownie networks: https://eth-brownie.readthedocs.io/en/latest/network-management.html
.. _Ganache CLI: https://github.com/trufflesuite/ganache-cli
